# anfrac

`anfrac` is a Python library providing a custom `Fraction` data type with basic arithmetic operations.
This is a first demo of the datatype, more additions will be coming soon.

## Installation

To install `anfrac`, run:

```bash
pip install anfrac
